### Name: covplot
### Title: Make "Forest Plots" of Covariate Effects, etc.
### Aliases: boxplot.prestats covplot
### Keywords: manip

### ** Examples

cov <- data.frame(                      #covariates
        WT=70 + rnorm(50)*10,           #weight, with some variance
        AGE=45+rnorm(50)*20,            #age, with some variance
        MALE=rep(c(TRUE,FALSE),50)      #half males, half females
)

boot <- data.frame(                     #bootstrap estimates
        CL=40 + rnorm(100)*5,           #parameter estimate for clearance
        WT=rnorm(100),                  #hovers around zero: no effect
        AGE=rnorm(
                100,
                mean=1,                 #hovers around 1: cl prop. to age
                sd=0.5                  #estimated imprecisely
        ),              
        MALE=rnorm(                     #categorical effect
                100,                                    
                mean=1.15,              #males have 15
                sd=0.05                 #estimated very precisely
        )
)
        
z.influence <- list(                    #encode side-by-side for sanity
        1, "x",                         #CL 
        cov$WT, "CL * (z/70)^x",        #WT ~ normalized WT to power: est.
        cov$AGE, "CL * (z/45)^x",       #AGE ~ normalized AGE to power: est.
        1, "CL * x^z"                   #MALE ~ est. to power: MALE
)
library(lattice)
boot <- as.distribution(
        boot,
        z=z.influence[c(TRUE,FALSE)],           #(just the odd elements)
        influence=z.influence[c(FALSE,TRUE)]    #(just the even elements)
)

covplot(CL~CL+AGE+WT+MALE,boot,rlim=0.2)



