### Name: miTemporal
### Title: Temporal Classes with Selective Defaults
### Aliases: miTemporal as.miTime as.miTime.character as.miTime.numeric
###   as.miTime.miTime as.miDate.character as.miDate as.miDate.numeric
###   as.miDate.miDate as.miDateTime as.miDateTime.character
###   as.miDateTime.numeric as.miDateTime.miDate as.miDateTime.miDateTime
###   format.miTime format.miDate format.miDateTime
### Keywords: manip

### ** Examples

#numeric to temporal
as.miTime(0)
# 00:00
as.miTime(1)
# 00:00+
as.miTime(-1)
# 23:59+
as.miTime(60)
# 00:01
as.miTime(-60)
# 23:59
as.miTime(86400)
# 00:00
as.miTime(86460)
# 00:01
as.miDate(0)
# 01/01/1970
as.miDate(1)
# 01/01/1970
as.miDate(-1)
# 12/31/1969
as.miDate(-86400)
# 12/31/1969
as.miDate(-86401)
# 12/30/1969
as.miDateTime(0)
# 01/01/1970 00:00
as.miDateTime(60)
# 01/01/1970 00:01 
as.miDateTime(61)
# 01/01/1970 00:01+
as.miDateTime(-1)
# 12/31/1969 23:59+

#character to temporal
as.miTime("00:00")
# 00:00
as.miTime("23:59")
# 23:59
as.miTime("23:59:00")
# 23:59
as.miTime("23:59:01")
# 23:59
as.miTime("23:59:01",format="%H:%M:%S")
# 23:59+
as.miTime("24:00")
# NA
as.miDate("1970-01-02")
# 01/02/1970
as.miDate("01/02/1970",format="%m/%d/%Y")
# 01/02/1970
as.miDateTime("01/02/1970 12:30",format="%m/%d/%Y %H:%M")
# 01/02/1970 12:30
as.miDateTime("01/02/1970 12:30:15",format="%m/%d/%Y %H:%M:%S")
# 01/02/1970 12:30+

#temporal to numeric
as.numeric(as.miTime(0))
# 0
as.numeric(as.miTime(1))
# 1
as.numeric(as.miTime(-1))
# 86399
as.numeric(as.miTime(60))
# 60
as.numeric(as.miTime(-60))
# 86340
as.numeric(as.miTime(86400))
# 0
as.numeric(as.miTime(86460))
# 60
as.numeric(as.miDate(0))
# 0
as.numeric(as.miDate(1))
# 0
as.numeric(as.miDate(-1))
# -86400
as.numeric(as.miDate(-86400))
# -86400
as.numeric(as.miDate(-86401))
# -172800
as.numeric(as.miDateTime(0))
# 0
as.numeric(as.miDateTime(60))
# 60 
as.numeric(as.miDateTime(61))
# 61
as.numeric(as.miDateTime(-1))
# -1
as.numeric(as.miTime("00:00"))
# 0
as.numeric(as.miTime("23:59"))
# 86340
as.numeric(as.miTime("23:59:00"))
# 86340
as.numeric(as.miTime("23:59:01"))
# 86340
as.numeric(as.miTime("23:59:01",format="%H:%M:%S"))
# 86341
as.numeric(as.miTime("24:00"))
# NA
as.numeric(as.miDate("1970-01-02"))
# 86400
as.numeric(as.miDate("01/02/1970",format="%m/%d/%Y"))
# 86400
as.numeric(as.miDateTime("01/02/1970 12:30",format="%m/%d/%Y %H:%M"))
# 131400
as.numeric(as.miDateTime("01/02/1970 12:30:15",format="%m/%d/%Y %H:%M:%S"))
# 131415

#temporal to character
as.character(as.miTime(0))
# "00:00"
as.character(as.miDate(0))
# "01/01/1970"
as.character(as.miDateTime(0))
# "01/01/1970 00:00"

#non-default printout
format(as.miTime(30000),format="%H")
# "08"
format(as.miDate("1970-01-01"),format="%d%b%y")
# 01Jan70
format(as.miDateTime("1970-01-02 23:30"),format="[%d/%m/%y %H:%M:%S]")
# "[02/01/70 23:30:00]"
format(as.miTime(1))
# "00:00+"
format(as.miTime(1),mark=FALSE)
# "00:00"

#sequence
seq(from=as.miTime("8:00"),to=as.miTime("12:00"))
# 08:00 09:00 10:00 11:00 12:00
seq(from=as.miDate("2008-01-01"),to=as.miDate("2008-01-04"))
# 01/01/2008 01/02/2008 01/03/2008 01/04/2008
seq(from=as.miDateTime("2008-01-01 12:00"),to=as.miDateTime("2008-01-04 12:30"))
# 01/01/2008 12:00 01/02/2008 12:00 01/03/2008 12:00 01/04/2008 12:00

#interconversion
as.miTime(as.miDate("2008-10-14"))
# 00:00
as.miTime(as.miDateTime("2008-10-14 08:00"))
# 08:00
as.miDate(as.miTime("23:59"))
# 01/01/1970
as.miDate(as.miDateTime("2008-10-14 08:00"))
# 10/14/2008
as.miDateTime(as.miTime(6000000))
# 01/01/1970 10:40
as.miDateTime(as.miDate("2008-10-14"))
# 10/14/2008 00:00

#infinity
as.miTime(Inf)
# Inf
as.miDate(Inf)
# Inf
as.miDateTime(Inf)
# Inf
as.miTime(-Inf)
# -Inf
as.miDateTime(Inf) + as.miTime(Inf)
# Inf
as.miDateTime(Inf) + as.miTime(-Inf)
# NA

#comparison
as.miTime("08:00") < as.miTime("09:00")
# TRUE
as.miDate("1970-01-01") > as.miDate("2008-01-01")
# FALSE
as.miDateTime("1970-01-01 08:00") > as.miDate("1970-01-01")
# TRUE

#statistics
max(as.miDate(c("1970-01-01","1980-01-01","1975-01-01")))
# 315532800

#operations
as.miDateTime(0) + as.miTime(60)
# 01/01/1970 00:01
as.miTime(60) + as.miDateTime(0)
# 00:01



